#!/usr/bin/env bash
set -xe
echo -e "\n\n" >> /opt/kafka/config/server.properties
HOSTNAME=`hostname -s`
HOST_ORDINAL=`echo ${HOSTNAME##*-}`
echo "Kafka broker id additive: $KAFKA_BROKER_ID_ADDITIVE"
BROKER_ID=$((HOST_ORDINAL+$KAFKA_BROKER_ID_ADDITIVE))
echo "broker.id: $(echo ${BROKER_ID})" >> /opt/kafka/config/server.properties
if [ "$ENABLE_ADVERTISED_LISTENERS" == "True" ]; then
  echo "advertised.listeners: $(echo ${ADVERTISED_LISTENERS})" >> /opt/kafka/config/server.properties
fi
echo "zookeeper.connect: $(echo ${ZOOKEEPER_CONNECT})" >> /opt/kafka/config/server.properties
echo "zookeeper.session.timeout.ms: $(echo ${ZOOKEEPER_SESSION_TIMEOUT_MS})" >> /opt/kafka/config/server.properties
echo "zookeeper.set.acl: $(echo ${ZOOKEEPER_SET_ACL})" >> /opt/kafka/config/server.properties
if [ "$DEPLOYED_IN_AWS" == true ] && [ "$DYNAMIC_RACK_ALLOCATION_ENABLED" == true ]; then
	BROKER_RACK=$(kubectl get node $NODE_NAME --no-headers --label-columns failure-domain.beta.kubernetes.io/region,failure-domain.beta.kubernetes.io/zone| awk '{print $7}')
else
	BROKER_RACK="cluster-1"
fi
echo "broker.rack: $(echo ${BROKER_RACK})" >> /opt/kafka/config/server.properties
echo "inter.broker.protocol.version: $(echo ${INTER_BROKER_PROTOCOL_VERSION})" >> /opt/kafka/config/server.properties
echo "background.threads: $(echo ${BACKGROUND_THREADS})" >> /opt/kafka/config/server.properties
echo "compression.type: $(echo ${COMPRESSION_TYPE})" >> /opt/kafka/config/server.properties
echo "broker.id.generation.enable: $(echo ${BROKER_ID_GENERATION_ENABLE})" >> /opt/kafka/config/server.properties
echo "reserved.broker.max.id: $(echo ${RESERVED_BROKER_MAX_ID})" >> /opt/kafka/config/server.properties
echo "controlled.shutdown.enable: $(echo ${CONTROLLED_SHUTDOWN_ENABLE})" >> /opt/kafka/config/server.properties
echo "controlled.shutdown.max.retries: $(echo ${CONTROLLED_SHUTDOWN_MAX_RETRIES})" >> /opt/kafka/config/server.properties
echo "controlled.shutdown.retry.backoff.ms: $(echo ${CONTROLLED_SHUTDOWN_RETRY_BACKOFF_MS})" >> /opt/kafka/config/server.properties
echo "controller.socket.timeout.ms: $(echo ${CONTROLLER_SOCKET_TIMEOUT_MS})" >> /opt/kafka/config/server.properties

echo "auto.create.topics.enable: $(echo ${AUTO_CREATE_TOPICS_ENABLE})" >> /opt/kafka/config/server.properties
echo "delete.topic.enable: $(echo ${DELETE_TOPIC_ENABLE})" >> /opt/kafka/config/server.properties

echo "log.dirs: $(echo ${DATA_DIRS})" >> /opt/kafka/config/server.properties
echo "log.message.format.version: $(echo ${LOG_MESSAGE_FORMAT_VERSION})" >> /opt/kafka/config/server.properties

echo "log.retention.bytes: $(echo ${LOG_RETENTION_BYTES})" >> /opt/kafka/config/server.properties
echo "log.retention.minutes: $(echo ${LOG_RETENTION_MINUTES})" >> /opt/kafka/config/server.properties
echo "log.retention.check.interval.ms: $(echo ${LOG_RETENTION_CHECK_INTERVAL_MS})" >> /opt/kafka/config/server.properties

echo "log.flush.interval.messages: $(echo ${LOG_FLUSH_INTERVAL_MESSAGES})" >> /opt/kafka/config/server.properties
echo "log.flush.offset.checkpoint.interval.ms: $(echo ${LOG_FLUSH_OFFSET_CHECKPOINT_INTERVAL_MS})" >> /opt/kafka/config/server.properties
echo "log.flush.scheduler.interval.ms: $(echo ${LOG_FLUSH_SCHEDULER_INTERVAL_MS})" >> /opt/kafka/config/server.properties

echo "log.segment.bytes: $(echo ${LOG_SEGMENT_BYTES})" >> /opt/kafka/config/server.properties
echo "log.segment.delete.delay.ms: $(echo ${LOG_SEGMENT_DELETE_DELAY_MS})" >> /opt/kafka/config/server.properties
echo "log.roll.hours: $(echo ${LOG_ROLL_HOURS})" >> /opt/kafka/config/server.properties
echo "log.roll.jitter.hours: $(echo ${LOG_ROLL_JITTER_HOURS})" >> /opt/kafka/config/server.properties

echo "log.cleaner.backoff.ms: $(echo ${LOG_CLEANER_BACKOFF_MS})" >> /opt/kafka/config/server.properties
echo "log.cleaner.dedupe.buffer.size: $(echo ${LOG_CLEANER_DEDUPE_BUFFER_SIZE})" >> /opt/kafka/config/server.properties
echo "log.cleaner.delete.retention.ms: $(echo ${LOG_CLEANER_DELETE_RETENTION_MS})" >> /opt/kafka/config/server.properties
echo "log.cleaner.enable: $(echo ${LOG_CLEANER_ENABLE})" >> /opt/kafka/config/server.properties
echo "log.cleaner.io.buffer.load.factor: $(echo ${LOG_CLEANER_IO_BUFFER_LOAD_FACTOR})" >> /opt/kafka/config/server.properties
echo "log.cleaner.io.buffer.size: $(echo ${LOG_CLEANER_IO_BUFFER_SIZE})" >> /opt/kafka/config/server.properties
echo "log.cleaner.io.max.bytes.per.second: $(echo ${LOG_CLEANER_IO_MAX_BYTES_PER_SECOND})" >> /opt/kafka/config/server.properties
echo "log.cleaner.min.cleanable.ratio: $(echo ${LOG_CLEANER_MIN_CLEANABLE_RATIO})" >> /opt/kafka/config/server.properties
echo "log.cleaner.min.compaction.lag.ms: $(echo ${LOG_CLEANER_MIN_COMPACTION_LAG_MS})" >> /opt/kafka/config/server.properties
echo "log.cleaner.threads: $(echo ${LOG_CLEANER_THREADS})" >> /opt/kafka/config/server.properties
echo "log.cleanup.policy: $(echo ${LOG_CLEANUP_POLICY})" >> /opt/kafka/config/server.properties
echo "log.index.interval.bytes: $(echo ${LOG_INDEX_INTERVAL_BYTES})" >> /opt/kafka/config/server.properties
echo "log.index.size.max.bytes: $(echo ${LOG_INDEX_SIZE_MAX_BYTES})" >> /opt/kafka/config/server.properties
echo "log.message.timestamp.difference.max.ms: $(echo ${LOG_MESSAGE_TIMESTAMP_DIFFERENCE_MAX_MS})" >> /opt/kafka/config/server.properties
echo "log.message.timestamp.type: $(echo ${LOG_MESSAGE_TIMESTAMP_TYPE})" >> /opt/kafka/config/server.properties
echo "log.preallocate: $(echo ${LOG_PREALLOCATE})" >> /opt/kafka/config/server.properties

echo "auto.leader.rebalance.enable: $(echo ${AUTO_LEADER_REBALANCE_ENABLE})" >> /opt/kafka/config/server.properties
echo "unclean.leader.election.enable: $(echo ${UNCLEAN_LEADER_ELECTION_ENABLE})" >> /opt/kafka/config/server.properties
echo "leader.imbalance.check.interval.seconds: $(echo ${LEADER_IMBALANCE_CHECK_INTERVAL_SECONDS})" >> /opt/kafka/config/server.properties
echo "leader.imbalance.per.broker.percentage: $(echo ${LEADER_IMBALANCE_PER_BROKER_PERCENTAGE})" >> /opt/kafka/config/server.properties

echo "default.replication.factor: $(echo ${DEFAULT_REPLICATION_FACTOR})" >> /opt/kafka/config/server.properties
echo "num.partitions: $(echo ${NUM_PARTITIONS})" >> /opt/kafka/config/server.properties
echo "min.insync.replicas: $(echo ${MIN_INSYNC_REPLICAS})" >> /opt/kafka/config/server.properties

echo "offset.metadata.max.bytes: $(echo ${OFFSET_METADATA_MAX_BYTES})" >> /opt/kafka/config/server.properties
echo "offsets.commit.required.acks: $(echo ${OFFSETS_COMMIT_REQUIRED_ACKS})" >> /opt/kafka/config/server.properties
echo "offsets.commit.timeout.ms: $(echo ${OFFSETS_COMMIT_TIMEOUT_MS})" >> /opt/kafka/config/server.properties
echo "offsets.load.buffer.size: $(echo ${OFFSETS_LOAD_BUFFER_SIZE})" >> /opt/kafka/config/server.properties
echo "offsets.retention.check.interval.ms: $(echo ${OFFSETS_RETENTION_CHECK_INTERVAL_MS})" >> /opt/kafka/config/server.properties
echo "offsets.retention.minutes: $(echo ${OFFSETS_RETENTION_MINUTES})" >> /opt/kafka/config/server.properties
echo "offsets.topic.compression.codec: $(echo ${OFFSETS_TOPIC_COMPRESSION_CODEC})" >> /opt/kafka/config/server.properties
echo "offsets.topic.num.partitions: $(echo ${OFFSETS_TOPIC_NUM_PARTITIONS})" >> /opt/kafka/config/server.properties
echo "offsets.topic.replication.factor: $(echo ${OFFSETS_TOPIC_REPLICATION_FACTOR})" >> /opt/kafka/config/server.properties
echo "offsets.topic.segment.bytes: $(echo ${OFFSETS_TOPIC_SEGMENT_BYTES})" >> /opt/kafka/config/server.properties

echo "quota.consumer.default: $(echo ${QUOTA_CONSUMER_DEFAULT})" >> /opt/kafka/config/server.properties
echo "consumer.byte.rate: $(echo ${CONSUMER_BYTE_RATE})" >> /opt/kafka/config/server.properties
echo "quota.producer.default: $(echo ${QUOTA_PRODUCER_DEFAULT})" >> /opt/kafka/config/server.properties
echo "producer.byte.rate: $(echo ${PRODUCER_BYTE_RATE})" >> /opt/kafka/config/server.properties

echo "replica.fetch.min.bytes: $(echo ${REPLICA_FETCH_MIN_BYTES})" >> /opt/kafka/config/server.properties
echo "replica.fetch.wait.max.ms: $(echo ${REPLICA_FETCH_WAIT_MAX_MS})" >> /opt/kafka/config/server.properties
echo "replica.high.watermark.checkpoint.interval.ms: $(echo ${REPLICA_HIGH_WATERMARK_CHECKPOINT_INTERVAL_MS})" >> /opt/kafka/config/server.properties
echo "replica.lag.time.max.ms: $(echo ${REPLICA_LAG_TIME_MAX_MS})" >> /opt/kafka/config/server.properties
echo "replica.socket.receive.buffer.bytes: $(echo ${REPLICA_SOCKET_RECEIVE_BUFFER_BYTES})" >> /opt/kafka/config/server.properties
echo "replica.socket.timeout.ms: $(echo ${REPLICA_SOCKET_TIMEOUT_MS})" >> /opt/kafka/config/server.properties
echo "replica.fetch.max.bytes: $(echo ${REPLICA_FETCH_MAX_BYTES})" >> /opt/kafka/config/server.properties
echo "replica.fetch.response.max.bytes: $(echo ${REPLICA_FETCH_RESPONSE_MAX_BYTES})" >> /opt/kafka/config/server.properties
echo "replica.fetch.backoff.ms: $(echo ${REPLICA_FETCH_BACKOFF_MS})" >> /opt/kafka/config/server.properties
echo "num.io.threads: $(echo ${NUM_IO_THREADS})" >> /opt/kafka/config/server.properties
echo "num.network.threads: $(echo ${NUM_NETWORK_THREADS})" >> /opt/kafka/config/server.properties
echo "num.recovery.threads.per.data.dir: $(echo ${NUM_RECOVERY_THREADS_PER_DATA_DIR})" >> /opt/kafka/config/server.properties
echo "num.replica.fetchers: $(echo ${NUM_REPLICA_FETCHERS})" >> /opt/kafka/config/server.properties

echo "message.max.bytes: $(echo ${MESSAGE_MAX_BYTES})" >> /opt/kafka/config/server.properties
echo "queued.max.requests: $(echo ${QUEUED_MAX_REQUESTS})" >> /opt/kafka/config/server.properties
echo "request.timeout.ms: $(echo ${REQUEST_TIMEOUT_MS})" >> /opt/kafka/config/server.properties
echo "socket.receive.buffer.bytes: $(echo ${SOCKET_RECEIVE_BUFFER_BYTES})" >> /opt/kafka/config/server.properties
echo "socket.request.max.bytes: $(echo ${SOCKET_REQUEST_MAX_BYTES})" >> /opt/kafka/config/server.properties
echo "socket.send.buffer.bytes: $(echo ${SOCKET_SEND_BUFFER_BYTES})" >> /opt/kafka/config/server.properties
echo "connections.max.idle.ms: $(echo ${CONNECTIONS_MAX_IDLE_MS})" >> /opt/kafka/config/server.properties

echo "fetch.purgatory.purge.interval.requests: $(echo ${FETCH_PURGATORY_PURGE_INTERVAL_REQUESTS})" >> /opt/kafka/config/server.properties
echo "group.initial.rebalance.delay.ms: $(echo ${GROUP_INITIAL_REBALANCE_DELAY_MS})" >> /opt/kafka/config/server.properties
echo "group.max.session.timeout.ms: $(echo ${GROUP_MAX_SESSION_TIMEOUT_MS})" >> /opt/kafka/config/server.properties
echo "group.min.session.timeout.ms: $(echo ${GROUP_MIN_SESSION_TIMEOUT_MS})" >> /opt/kafka/config/server.properties

echo "producer.purgatory.purge.interval.requests: $(echo ${PRODUCER_PURGATORY_PURGE_INTERVAL_REQUESTS})" >> /opt/kafka/config/server.properties

echo "max.connections.per.ip: $(echo ${MAX_CONNECTIONS_PER_IP})" >> /opt/kafka/config/server.properties

echo "listener.security.protocol.map: $(echo ${LISTENER_PROTOCOL_MAP})" >> /opt/kafka/config/server.properties

if [ "$DISABLE_SSL" == "False" ]; then
    # SSL
    if [ "$ENABLE_ADVERTISED_LISTENERS" == "True" ]; then
      echo "inter.broker.listener.name: $(echo ${INTER_BROKER_LISTENER_NAME})" >> /opt/kafka/config/server.properties
    else
      echo "security.inter.broker.protocol: $(echo ${INTER_BROKER_PROTOCOL})" >> /opt/kafka/config/server.properties
    fi
    echo "listeners: $(echo ${LISTENERS})" >> /opt/kafka/config/server.properties
    echo "ssl.mount.path: $(echo ${SSL_MOUNT_PATH})" >> /opt/kafka/config/server.properties
    echo "ssl.secure.random.implementation: $(echo ${SSL_RAND_IMPL})" >> /opt/kafka/config/server.properties

    export SSL_KEYSTORE_LOCATION_FULL_PATH=$SSL_MOUNT_PATH/$SSL_KEYSTORE_LOCATION
    echo "ssl.keystore.location: $(echo ${SSL_KEYSTORE_LOCATION_FULL_PATH})" >> /opt/kafka/config/server.properties
    echo "ssl.keystore.password: $(echo ${SSL_KEYSTORE_PASSWORD})" >> /opt/kafka/config/server.properties
    echo "ssl.key.password: $(echo ${SSL_KEY_PASSWORD})" >> /opt/kafka/config/server.properties

    export SSL_TRUSTSTORE_LOCATION_FULL_PATH=$SSL_MOUNT_PATH/$SSL_TRUSTSTORE_LOCATION
    echo "ssl.truststore.location: $(echo ${SSL_TRUSTSTORE_LOCATION_FULL_PATH})" >> /opt/kafka/config/server.properties
    echo "ssl.truststore.password: $(echo ${SSL_TRUSTSTORE_PASSWORD})" >> /opt/kafka/config/server.properties
    echo "ssl.endpoint.identification.algorithm:" >> /opt/kafka/config/server.properties

    echo "ssl.client.auth: $(echo ${SSL_CLIENT_AUTH})" >> /opt/kafka/config/server.properties
else
    echo "listeners: $(echo ${LISTENERS})" >> /opt/kafka/config/server.properties
    if [ "$ENABLE_ADVERTISED_LISTENERS" == "True" ]; then
      echo "inter.broker.listener.name: $(echo ${INTER_BROKER_LISTENER_NAME})" >> /opt/kafka/config/server.properties
    else
      echo "security.inter.broker.protocol: $(echo ${INTER_BROKER_PROTOCOL})" >> /opt/kafka/config/server.properties
    fi
    echo "SSL is disabled, so SSL properties not being appended"
fi